@@ -4,7 +4,7 @@ from __future__ import annotations
 from os.path import abspath, dirname, exists
 from os import mkdir
 from functools import reduce
-from typing import Dict, List, Tuple
+from typing import Dict, List, Tuple, Any
 from collections import OrderedDict, Counter
 from math import ceil, sqrt
 from datetime import datetime, date, time
@@ -12,6 +12,7 @@ from matplotlib import pyplot as plt
 from matplotlib.ticker import MultipleLocator, PercentFormatter, StrMethodFormatter, NullLocator, NullFormatter
 from matplotlib.dates import HourLocator, DateFormatter, MinuteLocator, MonthLocator, DayLocator
 import ray
+import seaborn as sns
 
 from .model.chat import Chat
 from .model.message import Message, MessageIndex
@@ -483,6 +484,93 @@ def plotConversationInitializerStat(data: Tuple[Counter, Counter], targetPath: s
         return False
 
 
+def prepareHeatMapData(data: List[Message]) -> Tuple[List[Dict[str, int]], List[str]]:
+    '''
+        Given list of messages sent on a date, for a 
+        certain user for chat under inspection, it'll create a
+        2D array, holding number of messages sent by user, over weekdays
+
+        Another list to be returned too, holding weekdays chronologically
+    '''
+    if not data:
+        return None, None
+
+    data = classifyMessagesOfChatByDate(data)
+
+    if not data:
+        return None, None
+
+    heatMapData = [{} for i in range(7)]
+    weekNumber = []
+
+    for i in data:
+
+        weekInfo = 'Week {} of {}'.format(
+            int(i.currentDate.strftime('%U'), base=10) + 1,
+            i.currentDate.strftime('%Y')
+        )
+
+        heatMapData[int(i.currentDate.strftime('%w'), base=10)].update({
+            weekInfo: i.count
+        })
+
+        if weekInfo not in weekNumber:
+            weekNumber.append(weekInfo)
+
+    _plottableData = [[] for i in range(7)]
+
+    for i, _week in enumerate(heatMapData):
+        tmp = _plottableData[i]
+
+        for k in weekNumber:
+            tmp.append(_week.get(k, 0))
+
+    return _plottableData, weekNumber
+
+
+@ray.remote
+def plotActivityHeatMap(data: List[Message], targetPath: str, title: str) -> bool:
+    '''
+        Plots heatmap of user activity across week days
+    '''
+    try:
+        if not data:
+            return False
+
+        font = {
+            'family': 'serif',
+            'color': '#000000',
+            'weight': 'normal',
+            'size': 16
+        }
+
+        _data, _weekIndices = prepareHeatMapData(data)
+
+        if not (_data and _weekIndices):
+            return False
+
+        fig = plt.figure(figsize=(24, 12), dpi=100)
+        axes = sns.heatmap(
+            _data,
+            cmap='Blues',
+            lw=.5)
+
+        axes.set_xticklabels(_weekIndices, rotation=90)
+        axes.set_yticklabels(['Sunday', 'Monday', 'Tuesday', 'Wednesday',
+                              'Thursday', 'Friday', 'Saturday'], rotation=0)
+        axes.set_title(title, fontdict=font, pad=14)
+        axes.set_xlabel('Week of Year', fontdict=font, labelpad=14)
+        axes.set_ylabel('Week Day', fontdict=font, labelpad=14)
+
+        plt.tight_layout()
+        plt.savefig(targetPath, bbox_inches='tight',
+                    pad_inches=.4, quality=95, dpi=100)
+        plt.close(fig)
+        return True
+    except Exception:
+        return False
+
+
 if __name__ == '__main__':
     print('[!]This module is designed to be used as a backend handler')
     exit(0)
